CharClassError

Enum CharClassError 

#[non_exhaustive]
pub enum CharClassError { Empty, CaretInGroup, NonAscendingRange(char, char), Invalid, Unallowed, UnknownNamedClass { found: Box<str>, extra_in_prefix: bool, }, Negative, UnexpectedPrefix, WrongPrefix { expected: &'static str, has_in_prefix: bool, }, }
An error that relates to a character class

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Empty

Empty character class, i.e. []



CaretInGroup

This error is created when [^ is encountered. This is a negated character class in a regex, but pomsky instead uses the ![ syntax.



NonAscendingRange(char, char)

Non-ascending code point range, e.g. ['z'-'a']



Invalid

Invalid token within a character class



Unallowed

Character class contains incompatible shorthands, e.g. [. codepoint]



UnknownNamedClass

Unknown shorthand character class or Unicode property

Fields

found: Box<str>
extra_in_prefix: bool


Negative

A character class that can’t be negated, e.g. [!ascii]



UnexpectedPrefix

The character class has a prefix where none is expected, e.g. [scx:w]



WrongPrefix

The character class has the wrong prefix, e.g. [sc:Basic_Latin] (the correct prefix would be block:)

Fields

expected: &'static str
has_in_prefix: bool