Enum pomsky_syntax::error::CharStringError
source · #[non_exhaustive]
pub enum CharStringError {
Empty,
TooManyCodePoints,
}Expand description
An error that relates to a character string
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
Empty string in a code point range within a character class, e.g.
[''-'z']
TooManyCodePoints
String in a code point range within a character class that contains
multiple code points, e.g. ['abc'-'z']