Enum pomsky_syntax::error::CodePointError
source · #[non_exhaustive]
pub enum CodePointError {
Invalid,
}Expand description
An error that relates to a Unicode code point
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Invalid
Code point that is outside the allowed range, e.g. U+200000