Module pomsky_syntax::exprs

source ·
Module containing the AST (abstract syntax tree) types for expressions

Structs

An alternation. This is a list of alternatives. Each alternative is a Rule.
A word boundary or anchor, which we combine under the term boundary.
A character class. Refer to the module-level documentation for details.
A group, i.e. sequence of rules. A group is either capturing or non-capturing.
A repetition in its most canonical form, {x,y}.

Enums

The contents of a CharClass.
One item in a character class.
A parsed pomsky expression, which might contain more sub-expressions.