Struct pomsky_syntax::exprs::Group

source ·
pub struct Group<'i> {
    pub parts: Vec<Rule<'i>>,
    pub kind: GroupKind<'i>,
    pub span: Span,
}
A group, i.e. sequence of rules. A group is either capturing or non-capturing.

If it is capturing, it must be wrapped in parentheses, and can have a name. If it is non-capturing, the parentheses can be omitted in same cases.

Fields

parts: Vec<Rule<'i>>kind: GroupKind<'i>span: Span

Implementations