Module pomsky_syntax::error
source · Expand description
Module containing all the errors that can occur during parsing
Structs
An error than can occur only during parsing
Enums
An error that relates to a character class
An error that relates to a character string
An error that relates to a Unicode code point
An error that is returned when a deprecated feature is used
An error message for a token that is invalid in a pomsky expression.
An error that relates to parsing a number
An error kind (without a span) than can occur only during parsing
An error indicating an invalid repetition, e.g.
x{4,2}A token encountered while lexing a pomsky expression.