Module pomsky_syntax::warning
source · Expand description
Provides warnings that are shown to the user (in addition to the output)
Structs
A warning.
Enums
A deprecation warning: Indicates that something shouldn’t be used anymore
A warning without a span pointing to the source of the warning